.. _astroML_regression:

Supervised Learning: Regression
===============================
More information will be here soon - check for updates!

Some examples of regression problems can be found in
:ref:`book_fig_chapter8`
